==> 0.0.3.tar.gz: lib/src/customerUnified/CustomerUnifiedModel.dart <==
import 'dart:convert';
import 'package:bar_tender_api_dart/src/CustomerUnified/CustomerUnified.dart';
import 'package:bar_tender_api_dart/src/CustomerUnified/CustomerUnifiedApiClient.dart';
import 'package:bar_tender_api_dart/src/models/Model.dart';
import 'package:bar_tender_api_dart/src/chart_item/ChartItem.dart';
import 'package:bar_tender_api_dart/src/customer/Customer.dart';
import 'package:bar_tender_api_dart/src/paths.dart';
import 'package:bar_tender_api_dart/src/recipe_item_custom/RecipeItemCustom.dart';
import 'package:bar_tender_api_dart/src/review/Review.dart';
import 'package:flutter/material.dart';
import 'package:flutter_secure_storage/flutter_secure_storage.dart';
import 'package:http/http.dart';

class CustomerUnifiedModel extends Model<CustomerUnified> {

  String username;
  String password;
  Widget loginWidget;
  int _timesFetched = 0;
  int get timesFetched => _timesFetched;

  static const storage = FlutterSecureStorage();
  static String usernameKey = "username";
  static String passwordKey = "password";

  CustomerUnifiedModel({this.username = "", this.password = "", this.loginWidget = const Text('Insert a Widget to display')}):
        super(
          urlPath: _buildUrl(username, password),
          apiClient: CustomerUnifiedApiClient(),
          value: CustomerUnified.empty());

  static String _buildUrl(String username, String password) {
    return "${CUSTOMER_UNIFIED_API_PATH}login?username=$username&password=$password";
  }

  Future<void> updateUrl(String username, String password) async {
    this.username = username;
    this.password = password;
    urlPath = _buildUrl(username, password);
    await storage.write(key: usernameKey, value: this.username);
    await storage.write(key: passwordKey, value: this.password);
  }

  Future<CustomerUnifiedModel> initializeFromSecureStorage() async {
    String? storedUsername = await storage.read(key: usernameKey);
    String? storedPassword = await storage.read(key: passwordKey);

    username = storedUsername ?? "";
    password = storedPassword ?? "";
    urlPath = _buildUrl(username, password);
    if (username.isNotEmpty && password.isNotEmpty) {
      fetch();
    }
    return this;
  }

  @override
  Future<void> fetch() async {
    if (username.isEmpty || password.isEmpty) {
      errorMessage = "Username o password non impostati";
      return;
    }
    _timesFetched++;
    super.fetch();
  }

  @override
  String toJson(CustomerUnified element) => jsonEncode(element);

  @override
  CustomerUnified fromJson(dynamic json) => CustomerUnified.fromJson(json);

  @override
  bool isValueEmpty() => value.customer.id == 0;

  @override
  List toList() => value.dispensersWithIngredients?.values.toList() ?? [];

  Future<Response> addToChart(ChartItem chartItem) {
    return apiClient.createOrUpdate(this, chartItem);
  }

  Future<Response> addCredit(int amount) {
    return apiClient.genericGet("$CUSTOMER_ADD_CREDIT_API_PATH?idUser=${value.customer.id}&credit=$amount");
  }

  Future<Response> addCustomRecipe(int idCustomer, int idDrink, List<RecipeItemCustom> recipeItems) {
    var request = "$UPDATE_OR_SAVE_CUSTOM_RECIPE?idUser=$idCustomer&idDrink=$idDrink";
    return apiClient.genericPost(request, jsonEncode(recipeItems));
  }

  Future<Response> sendNewReview(Review review) async {
    review.idCustomer = value.customer.id;
    review.codCustomer = value.customer.codCustomer;
    return apiClient.genericPost(REVIEW_API_PATH, jsonEncode(review));
  }

  Future<Response> registerUser(Customer customer) {
    return apiClient.genericPost(CUSTOMER_API_PATH, jsonEncode(customer));
  }

  bool isInitialize () {
    return username.isNotEmpty && password.isNotEmpty && value.customer.id != 0;
  }

  Future<void> logUserModalWidget(BuildContext context, String title) async {
    return await showModalBottomSheet<void>(
      context: context,
      isScrollControlled: true,
      builder: (BuildContext context) {
        return ClipRRect(
          borderRadius: BorderRadius.circular(16.0),
          child: Container(
            height: MediaQuery.of(context).size.height * 0.9,
            color: Theme.of(context).colorScheme.primaryContainer,
            child: Padding(
              padding: const EdgeInsets.all(24.0),
              child: loginWidget
            ),
          ),
        );
      },
    );
  }

  Widget logUserPageWidget(String title) {
    return Padding(
      padding: const EdgeInsets.all(8.0),
      child: loginWidget,
    );
  }

  Future<void> reset() async {
    await updateUrl("", "");
    _timesFetched = 0;
    setValue = CustomerUnified.empty();
  }

  Future<Response> dispenserUserHandhake(String fullCode) async {
    return apiClient.genericPost("$HANDSHAKE_CONTACT_DISPENSER?id_user=${value.customer.id}&qr_code_data=$fullCode", "");
  }

}

==> 0.0.10.tar.gz: lib/src/customerUnified/CustomerUnifiedModel.dart <==
import 'dart:convert';
import 'package:bar_tender_api_dart/src/customerUnified/CustomerUnified.dart';
import 'package:bar_tender_api_dart/src/customerUnified/CustomerUnifiedApiClient.dart';
import 'package:bar_tender_api_dart/src/models/Model.dart';
import 'package:bar_tender_api_dart/src/chart_item/ChartItem.dart';
import 'package:bar_tender_api_dart/src/customer/Customer.dart';
import 'package:bar_tender_api_dart/src/paths.dart';
import 'package:bar_tender_api_dart/src/recipe_item_custom/RecipeItemCustom.dart';
import 'package:bar_tender_api_dart/src/review/Review.dart';
import 'package:flutter_secure_storage/flutter_secure_storage.dart';
import 'package:http/http.dart';

class CustomerUnifiedModel extends Model<CustomerUnified> {

  String username;
  String password;
  int _timesFetched = 0;
  int get timesFetched => _timesFetched;

  static const storage = FlutterSecureStorage();
  static String usernameKey = "username";
  static String passwordKey = "password";

  CustomerUnifiedModel({this.username = "", this.password = ""}):
        super(
          urlPath: _buildUrl(username, password),
          apiClient: CustomerUnifiedApiClient(),
          value: CustomerUnified.empty());

  static String _buildUrl(String username, String password) {
    return "${CUSTOMER_UNIFIED_API_PATH}login?username=$username&password=$password";
  }

  Future<void> updateUrl(String username, String password) async {
    this.username = username;
    this.password = password;
    urlPath = _buildUrl(username, password);
    await storage.write(key: usernameKey, value: this.username);
    await storage.write(key: passwordKey, value: this.password);
  }

  Future<CustomerUnifiedModel> initializeFromSecureStorage() async {
    String? storedUsername = await storage.read(key: usernameKey);
    String? storedPassword = await storage.read(key: passwordKey);

    username = storedUsername ?? "";
    password = storedPassword ?? "";
    urlPath = _buildUrl(username, password);
    if (username.isNotEmpty && password.isNotEmpty) {
      fetch();
    }
    return this;
  }

  @override
  Future<void> fetch() async {
    if (username.isEmpty || password.isEmpty) {
      errorMessage = "Username o password non impostati";
      return;
    }
    _timesFetched++;
    super.fetch();
  }

  @override
  String toJson(CustomerUnified element) => jsonEncode(element);

  @override
  CustomerUnified fromJson(dynamic json) => CustomerUnified.fromJson(json);

  @override
  bool isValueEmpty() => value.customer.id == 0;

  @override
  List toList() => value.dispensersWithIngredients?.values.toList() ?? [];

  Future<Response> addToChart(ChartItem chartItem) {
    return apiClient.createOrUpdate(this, chartItem);
  }

  Future<Response> addCredit(int amount) {
    return apiClient.genericGet("$CUSTOMER_ADD_CREDIT_API_PATH?idUser=${value.customer.id}&credit=$amount");
  }

  Future<Response> addCustomRecipe(int idCustomer, int idDrink, List<RecipeItemCustom> recipeItems) {
    var request = "$UPDATE_OR_SAVE_CUSTOM_RECIPE?idUser=$idCustomer&idDrink=$idDrink";
    return apiClient.genericPost(request, jsonEncode(recipeItems));
  }

  Future<Response> sendNewReview(Review review) async {
    review.idCustomer = value.customer.id;
    review.codCustomer = value.customer.codCustomer;
    return apiClient.genericPost(REVIEW_API_PATH, jsonEncode(review));
  }

  Future<Response> registerUser(Customer customer) {
    return apiClient.genericPost(CUSTOMER_API_PATH, jsonEncode(customer));
  }

  bool isInitialize () {
    return username.isNotEmpty && password.isNotEmpty && value.customer.id != 0;
  }


  Future<void> reset() async {
    await updateUrl("", "");
    _timesFetched = 0;
    setValue = CustomerUnified.empty();
  }

  Future<Response> dispenserUserHandhake(String fullCode) async {
    return apiClient.genericPost("$HANDSHAKE_CONTACT_DISPENSER?id_user=${value.customer.id}&qr_code_data=$fullCode", "");
  }

}
